import React, {message, useContext, useEffect} from "react";
import {useStore} from "../../utils/useStore";
import {Card, Tabs} from "antd";
import {BreadcumbComponent} from "../../component/BreadcumbComponent";
import {Product} from "./Product";
import {LINKS} from "../../routes/app";
import {observer} from "mobx-react-lite";
import {ModalLoaderContext} from "../../utils/modal";

const {TabPane} = Tabs;

export const Transaction = observer(() => {
  const store = useStore();

  const modalLoader = useContext(ModalLoaderContext);

  useEffect(() => {
    const init = async () => {
      try {
        modalLoader.setLoading(true);
        await store.transaction.getDataCategories();
        modalLoader.setLoading(false);
      } catch (e) {
        modalLoader.setLoading(false);
        if (e.response?.body?.message) {
          message.error(e.response.body.message);
          return;
        }
        message.error(e.message);
      }
    };

    init();
  }, []);

  const handleChangeTabs = async (key) => {
    modalLoader.setLoading(true);
    store.transaction.dataSubCategories = [];
    store.transaction.data = [];
    store.transaction.filterSubCategory = null;
    store.transaction.filterCategory = key;
    await store.transaction.getDataSubCategories();
    modalLoader.setLoading(false);
  };

  const routeData = [
    {
      route: LINKS.HOME,
      name: "Beranda",
    },
    {
      route: LINKS.TRANSACTION,
      name: <span style={{fontWeight: 'bold'}}>Transaksi</span>,
    },
  ];

  return (
    <div className={["ppob-container"].join(" ")}>
      <BreadcumbComponent data={routeData} text=""/>
      <Card>
        <Tabs
          onChange={handleChangeTabs}
          size="default"
          tabBarGutter="50"
        >
          {store.transaction.dataCategories.map((item, index) => (
            <TabPane tab={item.name} key={item.id}>
              <Product/>
            </TabPane>
          ))}

        </Tabs>
      </Card>
    </div>
  );
});
